@@ -3,7 +3,7 @@ package App::ClusterSSH;
 use 5.008.004;
 use warnings;
 use strict;
-use version; our $VERSION = version->new('4.02_02');
+use version; our $VERSION = version->new('4.02_04');
 
 use Carp;
 
@@ -46,7 +46,7 @@ use Socket;
 # load cfg files from options
 # overlay rest of cmd line args onto options
 # record all clusters
-# parse givwen tags/hostnames and resolve to connections
+# parse given tags/hostnames and resolve to connections
 # open terminals
 # optionally open console if required
 
@@ -98,7 +98,7 @@ my @options_spec = (
     'man|H',
     'action|a=s',
     'cluster-file|c=s',
-    'tag-file|c=s',
+    'tag-file|r=s',
     'config-file|C=s',
     'evaluate|e=s',
     'tile|g',
@@ -178,10 +178,9 @@ sub terminate_host($) {
 sub exit_prog() {
     logmsg( 3, "Exiting via normal routine" );
 
-    # for each of the client windows, send a kill
-
-    # to make sure we catch all children, even when they havnt
-    # finished starting or received teh kill signal, do it like this
+    # for each of the client windows, send a kill.
+    # to make sure we catch all children, even when they haven't
+    # finished starting or received the kill signal, do it like this
     while (%servers) {
         foreach my $svr ( keys(%servers) ) {
             terminate_host($svr);
@@ -341,7 +340,7 @@ sub load_keyboard_map() {
         }
     }
 
-    # dont know these two key combs yet...
+    # don't know these two key combs yet...
     #$keyboardmap{ $keycodetosym { $keyboard[$_][4] } } = $_ + $min;
     #$keyboardmap{ $keycodetosym { $keyboard[$_][5] } } = $_ + $min;
 
@@ -406,12 +405,14 @@ sub resolve_names(@) {
             my $hostobj = gethostbyname($dirty);
             if ( defined($hostobj) ) {
                 my @alladdrs = map { inet_ntoa($_) } @{ $hostobj->addr_list };
+                $self->cluster->register_tag( $dirty, @alladdrs );
                 if ( $#alladdrs > 0 ) {
-                    $self->cluster->register_tag( $dirty, @alladdrs );
                     logmsg( 3, 'Expanded to ',
-                        $self->cluster->get_tag($dirty) );
+                        join(' ', $self->cluster->get_tag($dirty) ) );
+                    @tag_list = $self->cluster->get_tag($dirty);
                 }
                 else {
+                    # don't expand if there is only one record found
                     logmsg( 3, 'Only one A record' );
                 }
             }
@@ -634,7 +635,7 @@ sub send_resizemove($$$$$) {
         32,
         'Replace',
 
-        # create data struct on fly to set bitwise flags
+        # create data struct on-the-fly to set bitwise flags
         pack( 'LLLLL' . 'x[L]' x 12, 1 | 2, $x_pos, $y_pos, $x_siz, $y_siz ),
     );
 
@@ -719,7 +720,7 @@ sub open_client_windows(@) {
         mkfifo( $servers{$server}{pipenm}, 0600 )
             or die("Cannot create pipe: $!");
 
-       # NOTE: the pid is re-fetched from the xterm window (via helper_script)
+       # NOTE: the PID is re-fetched from the xterm window (via helper_script)
        # later as it changes and we need an accurate PID as it is widely used
         $servers{$server}{pid} = fork();
         if ( !defined( $servers{$server}{pid} ) ) {
@@ -755,7 +756,7 @@ sub open_client_windows(@) {
         }
     }
 
-    # Now all the windows are open, get all their window id's
+    # Now all the windows are open, get all their window IDs
     foreach my $server ( keys(%servers) ) {
         next if ( defined( $servers{$server}{active} ) );
 
@@ -881,7 +882,7 @@ sub show_console() {
     return $self;
 }
 
-# leave function def open here so we can be flexible in how it called
+# leave function def open here so we can be flexible in how it's called
 sub retile_hosts {
     my ( $self, $force ) = @_;
     $force ||= "";
@@ -1234,7 +1235,7 @@ sub build_hosts_menu() {
 
     logmsg( 3, "Menu deleted" );
 
-    # add back the seperator
+    # add back the separator
     $menus{hosts}->separator;
 
     logmsg( 3, "Parsing list" );
@@ -1692,7 +1693,7 @@ sub create_menubar() {
         -menuitems => [
             [   "command",
                 "Show History",
-                -command     => \&show_history,
+                -command     => sub{ $self->show_history; },
                 -accelerator => $self->config->{key_history},
             ],
             [   "command",
@@ -1880,7 +1881,7 @@ sub run {
     my ($self) = @_;
 ### main ###
 
-    # Note: getopts returned "" if it finds any options it doesnt recognise
+    # Note: getopts returns "" if it finds any options it doesn't recognise
     # so use this to print out basic help
     pod2usage( -verbose => 1 )
         if ( !GetOptions( \%options, @options_spec ) );
@@ -1923,6 +1924,11 @@ sub run {
 
     $self->config->load_configs( $options{'config-file'} );
 
+    if ( $options{title} ) {
+        $self->config->{title} = $options{title};
+        logmsg( 2, "Title: " . $self->config->{title} );
+    }
+
     if ( $options{use_all_a_records} ) {
         $self->config->{use_all_a_records}
             = !$self->config->{use_all_a_records} || 0;
@@ -2061,7 +2067,7 @@ for F<cssh>, F<crsh>, F<ctel>, F<ccon>, or F<cscp> instead.
 
 =head1 DESCRIPTION
 
-THis is the core for App::ClusterSSH.  You should probably look at L<cssh> 
+This is the core for App::ClusterSSH.  You should probably look at L<cssh> 
 instead.
 
 =head1 SUBROUTINES/METHODS
